@@ -591,7 +591,7 @@ void xyscanBaseWindow::createHistogramDockingWidget()
     //
     addDockWidget(Qt::TopDockWidgetArea, mHistogramDock); // widget area is only a dummy here
     mHistogramDock->toggleViewAction()->setText(tr("&Density Histogram"));
-    mHistogramDock->toggleViewAction()->setShortcut(Qt::CTRL + Qt::Key_G);
+    mHistogramDock->toggleViewAction()->setShortcut(Qt::CTRL | Qt::Key_G);
 
     mViewMenu->addAction(mHistogramDock->toggleViewAction());
     mHistogramDock->setFloating(true);
@@ -854,7 +854,7 @@ void xyscanBaseWindow::createMenuActions()
     mEditCommentAction->setShortcut(QKeySequence::AddTab);
 
     mShowPrecisionAction = new QAction(tr("&Current Precision"), this);
-    mShowPrecisionAction->setShortcut(Qt::CTRL + Qt::Key_I);
+    mShowPrecisionAction->setShortcut(Qt::CTRL | Qt::Key_I);
 
     mScreenScanAction = new QAction(tr("Scan Screen"), this);
     mScreenScanAction->setCheckable(true);
@@ -978,7 +978,7 @@ void xyscanBaseWindow::createTableDockingWidget()
     mTableDock->setWidget(tableDockContents);
     addDockWidget(Qt::BottomDockWidgetArea, mTableDock);
     mTableDock->toggleViewAction()->setText(tr("&Data Table"));
-    mTableDock->toggleViewAction()->setShortcut(Qt::CTRL + Qt::Key_D );
+    mTableDock->toggleViewAction()->setShortcut(Qt::CTRL | Qt::Key_D );
 
     mViewMenu->addAction(mTableDock->toggleViewAction());
     mTableDock->setFloating(true);
@@ -1181,7 +1181,7 @@ void xyscanBaseWindow::createZoomDockingWidget()
 
     addDockWidget(Qt::TopDockWidgetArea, mZoomDock); // widget area is only a dummy here
     mZoomDock->toggleViewAction()->setText(tr("&Cursor Zoom"));
-    mZoomDock->toggleViewAction()->setShortcut(Qt::CTRL + Qt::Key_Y);
+    mZoomDock->toggleViewAction()->setShortcut(Qt::CTRL | Qt::Key_Y);
 
     mViewMenu->addAction(mZoomDock->toggleViewAction());
     mZoomDock->setFloating(true);
