@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-//  Copyright (C) 2002-2020 Thomas S. Ullrich
+//  Copyright (C) 2002-2022 Thomas S. Ullrich
 //
 //  This file is part of "xyscan".
 //
@@ -8,7 +8,7 @@
 //  under the terms of the GNU General Public License.
 //
 //  Author: Thomas S. Ullrich
-//  Last update: March 4, 2020
+//  Last update: Jan 10, 2022
 //-----------------------------------------------------------------------------
 #ifndef xyscanDataTable_h
 #define xyscanDataTable_h
@@ -40,12 +40,14 @@ public:
     void addColumnsForXError();
     void addColumnsForYError();
     void resetColumns();
+    void resetAll();
 
     void writePrinterDocument(QTextDocument&, const QString&, const QImage* = nullptr);
     void writeRootMacro(QFile&, const QString&, bool, bool, double mc[4]);
     void writeTextFile(QFile&, const QString&);
     void writeCsvFile(QFile&, const QString&);
 
+    double value(int, int) const;
     double x(int) const;
     double y(int) const;
     double dx_lower(int, int) const;
@@ -75,7 +77,7 @@ inline bool xyscanDataTable::dataSaved() const {return mDataSaved;}
 inline void xyscanDataTable::setDataSaved(bool val) {mDataSaved = val;}
 inline QString xyscanDataTable::userComment() const {return mUserComment;}
 inline void xyscanDataTable::setUserComment(const QString& str) {mUserComment = str;}
-inline double xyscanDataTable::x(int i) const {return item(i, 0)->text().toDouble();}
-inline double xyscanDataTable::y(int i) const {return item(i, 1)->text().toDouble();}
+inline double xyscanDataTable::x(int i) const {return value(i, 0);}
+inline double xyscanDataTable::y(int i) const {return value(i, 1);}
 
 #endif
