@@ -33,12 +33,6 @@ int main(int argc, char *argv[])
     app.setApplicationVersion(VERSION);
     app.setApplicationName("xyscan");
 
-    //
-    //  Set attributes related to high resolution displays
-    //
-    if (QGuiApplication::primaryScreen()->devicePixelRatio() > 1)
-        app.setAttribute(Qt::AA_UseHighDpiPixmaps);
-    
     //
     //  Internationalization
     //  Load translator unless we are using English.
