@@ -360,6 +360,7 @@ void xyscanWindow::connectToolBoxActions()
 
     QShortcut *shortcutM = new QShortcut(Qt::CTRL | Qt::Key_M, mMeasureItem);
     connect(shortcutM, &QShortcut::activated, [=](){this->enableMeasuring(!mMeasuringIsOn);});
+
 }
 
 void xyscanWindow::createSettingMarkerActions()
@@ -368,7 +369,7 @@ void xyscanWindow::createSettingMarkerActions()
     connect(mSetUpperXButton, &QPushButton::clicked, [=](){this->setPlotCoordinateValueForMarker(mXUpper);});
     connect(mSetLowerYButton, &QPushButton::clicked, [=](){this->setPlotCoordinateValueForMarker(mYLower);});
     connect(mSetUpperYButton, &QPushButton::clicked, [=](){this->setPlotCoordinateValueForMarker(mYUpper);});
-    
+
     QShortcut *shortcut1 = new QShortcut(Qt::CTRL | Qt::Key_1, mSetLowerXButton);
     QShortcut *shortcut2 = new QShortcut(Qt::CTRL | Qt::Key_2, mSetUpperXButton);
     QShortcut *shortcut3 = new QShortcut(Qt::CTRL | Qt::Key_3, mSetLowerYButton);
@@ -377,7 +378,7 @@ void xyscanWindow::createSettingMarkerActions()
     connect(shortcut1, &QShortcut::activated, [=](){this->setPlotCoordinateValueForMarker(mXLower);});
     connect(shortcut2, &QShortcut::activated, [=](){this->setPlotCoordinateValueForMarker(mXUpper);});
     connect(shortcut3, &QShortcut::activated, [=](){this->setPlotCoordinateValueForMarker(mYLower);});
-    connect(shortcut4, &QShortcut::activated, [=](){this->setPlotCoordinateValueForMarker(mYUpper);});
+    connect(shortcut4, &QShortcut::activated, [=](){this->setPlotCoordinateValueForMarker(mYUpper);});    
 }
 
 
@@ -544,6 +545,28 @@ bool xyscanWindow::eventFilter(QObject *obj, QEvent *event)
 {
     if (!event) return false;
 
+    //
+    //  This is to avoid confusion on how to set axis marker values.
+    //  When user clicks on the read-only field the same action as when
+    //  pushing the 'Set' button takes place: the popup window opens
+    //  to set the value. This has to be done here since the line edit
+    //  fiels is read-only and signals don't work.
+    //
+    if (event->type() == QEvent::MouseButtonRelease) {
+        if (obj == mLowerXValueField && mSetLowerXButton->isEnabled()) {
+            setPlotCoordinateValueForMarker(mXLower);
+        }
+        else if (obj == mLowerYValueField && mSetLowerYButton->isEnabled()) {
+            setPlotCoordinateValueForMarker(mYLower);
+        }
+         else if (obj == mUpperXValueField && mSetUpperXButton->isEnabled()) {
+            setPlotCoordinateValueForMarker(mXUpper);
+        }
+        else if (obj == mUpperYValueField && mSetUpperYButton->isEnabled()) {
+            setPlotCoordinateValueForMarker(mYUpper);
+        }
+    }
+
     //
     //  First we see if this is an FileOpen event passed
     //  along from the application. On the Mac this means
@@ -1272,7 +1295,7 @@ void xyscanWindow::openFromFile(const QString& filename)
         //   Load PDF file
         //
         QPdfDocument document(this);
-        if (document.load(filename) != QPdfDocument::DocumentError::NoError) {
+        if (document.load(filename) != QPdfDocument::Error::None) {
             QMessageBox::warning(0, "xyscan", tr("Cannot open PDF file '%1'.").arg(filename));
             return;
         }
@@ -1299,7 +1322,7 @@ void xyscanWindow::openFromFile(const QString& filename)
         //
         //   Now deal with the size with which to render the page
         //
-        QSizeF pageSize = document.pageSize(pageNumber-1);  // page counts starts at 0
+        QSizeF pageSize = document.pagePointSize(pageNumber-1);  // page counts starts at 0
         double pdfScale = QInputDialog::getDouble(this, tr("Scale"),
                                                   tr("PDF can be scaled before loading.\n"
                                                      "Original resolution is %1 x %2.\n"
